==> haskell-http-conduit-2.1.10.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.1.10.1
id: http-conduit-2.1.10.1-DrS3Vpny37J3EYy8WwtAWK
key: http-conduit-2.1.10.1-DrS3Vpny37J3EYy8WwtAWK
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
    Network.HTTP.Simple
abi: e4e869426fa01202e64168abc6430a75
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.1.10.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.1.10.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/http-conduit-2.1.10.1
hs-libraries: HShttp-conduit-2.1.10.1-DrS3Vpny37J3EYy8WwtAWK
depends:
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
    conduit-extra-1.1.13.1-l1HsAoHEKPFqe5VO2k2qY
    data-default-class-0.1.1-Ly61bORoJc16r3Tjbg7Q3c
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf
    http-client-0.4.29-EpK4NDQPEvP4svI1eyv5FV
    http-client-tls-0.2.4.1-B3FoXGKR5bEGTPdFdXWwK6
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    lifted-base-0.2.3.6-1j3h4N3dJlkKcS6HOknNA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-conduit-2.1.10.1-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-conduit
version: 2.1.10.1
id: http-conduit-2.1.10.1-4FTdKBkVtbn4RkZbHpbK9Y
key: http-conduit-2.1.10.1-4FTdKBkVtbn4RkZbHpbK9Y
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/http-conduit
synopsis: HTTP client package with conduit interface and HTTPS support.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-conduit>.
category: Web, Conduit
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.HTTP.Conduit Network.HTTP.Client.Conduit
    Network.HTTP.Simple
abi: a039ddc61cdc4cf6c39a666c9a249311
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.1.10.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-conduit-2.1.10.1
data-dir: /usr/share/arm-linux-ghc-8.0.1/http-conduit-2.1.10.1
hs-libraries: HShttp-conduit-2.1.10.1-4FTdKBkVtbn4RkZbHpbK9Y
depends:
    aeson-0.11.2.0-FbOoMAnyGWNAFaN63GUEkg base-4.9.0.0
    bytestring-0.10.8.1 conduit-1.2.6.6-DP6wmtnPfNiE72BJILsUMh
    conduit-extra-1.1.13.1-l1HsAoHEKPFqe5VO2k2qY
    data-default-class-0.1.2.0-6eetmQ6CbQOLoXb6k5kODu
    exceptions-0.8.2.1-BH4VJoBlnhODiEIhn43wEf
    http-client-0.4.29-EtQb8ICZHPvBn1LeWKC2sO
    http-client-tls-0.2.4.1-9jrDUqgy1JQBTHKUfBhE4i
    http-types-0.9.1-COSfHHdOet5Sq6KAE7lWN
    lifted-base-0.2.3.6-1j3h4N3dJlkKcS6HOknNA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.7.4-5MzcrbA8GQD6CRuZwV7nMM transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-http-conduit/html/http-conduit.haddock
haddock-html: /usr/share/doc/haskell-http-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
